// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `geor` vocabulary
//!
//! This module requires `ns-geor` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**||
//! |**Prefix**|geor|
//! |**Namespace base IRI**|<http://www.opengis.net/def/rule/geosparql/>|
//! |**Description**||
//! |**Is defined by**|<http://www.opengis.net/def/rule/geosparql/>|
//!

use crate::namespace;

namespace!(
    "http://www.opengis.net/def/rule/geosparql/",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `ehContains`: 
    ehContains, "ehContains",
    /// `ehCoveredBy`: 
    ehCoveredBy, "ehCoveredBy",
    /// `ehCovers`: 
    ehCovers, "ehCovers",
    /// `ehDisjoint`: 
    ehDisjoint, "ehDisjoint",
    /// `ehEquals`: 
    ehEquals, "ehEquals",
    /// `ehInside`: 
    ehInside, "ehInside",
    /// `ehMeet`: 
    ehMeet, "ehMeet",
    /// `ehOverlap`: 
    ehOverlap, "ehOverlap",
    /// `rcc8dc`: 
    rcc8dc, "rcc8dc",
    /// `rcc8ec`: 
    rcc8ec, "rcc8ec",
    /// `rcc8eq`: 
    rcc8eq, "rcc8eq",
    /// `rcc8ntpp`: 
    rcc8ntpp, "rcc8ntpp",
    /// `rcc8ntppi`: 
    rcc8ntppi, "rcc8ntppi",
    /// `rcc8po`: 
    rcc8po, "rcc8po",
    /// `rcc8tpp`: 
    rcc8tpp, "rcc8tpp",
    /// `rcc8tppi`: 
    rcc8tppi, "rcc8tppi",
    /// `sfContains`: 
    sfContains, "sfContains",
    /// `sfCrosses`: 
    sfCrosses, "sfCrosses",
    /// `sfDisjoint`: 
    sfDisjoint, "sfDisjoint",
    /// `sfEquals`: 
    sfEquals, "sfEquals",
    /// `sfIntersects`: 
    sfIntersects, "sfIntersects",
    /// `sfOverlaps`: 
    sfOverlaps, "sfOverlaps",
    /// `sfTouches`: 
    sfTouches, "sfTouches",
    /// `sfWithin`: 
    sfWithin, "sfWithin"
);
